Skip to contents

A function for retrieving vote decisions from a specific vote. Vote data are only available from the 2011-2012 session

Usage

get_decision_votes(voteid = NA, good_manners = 0)

Arguments

voteid

Character string, or a vector of strings, indicating the id of the vote to retrieve decisions from

good_manners

Integer. Seconds delay between calls when making multiple calls to the same function. Note that the Stortinget API is limited to 100 calls per minute (see https://data.stortinget.no/nyhetsoversikt/begrensning-pa-api-kall/).

Value

A data.frame with the following variables:

response_dateDate of data retrieval
versionData version from the API
vote_idId of the vote
decision_codeGeneral code for decision
decision_commentComments for the decision
decision_numberDecision number
decision_referenceReference for the decision
decision_textFull text of the decision

Examples

if (FALSE) { # \dontrun{
decision <- get_decision_votes(123)
decision
} # }