Get list of MPs in a given parliamentary period
Source:R/get_parlperiod_mps.R
get_parlperiod_mps.RdA function for retrieving Norwegian MPs for a given parliamentary period from the parliament API
Arguments
- periodid
Character string, or a vector of strings, indicating the id of the parliamentary period to retrieve.
- substitute
Logical. Whether or not to include substitute MPs.
- good_manners
Integer. Seconds delay between calls when making multiple calls to the same function. Note that the Stortinget API is limited to 100 calls per minute (see https://data.stortinget.no/nyhetsoversikt/begrensning-pa-api-kall/).
Value
A data.frame with the following variables:
| response_date | Date of data retrieval |
| version | Data version from the API |
| death | Date of death |
| lastname | MP last name |
| birth | Date of birth |
| firstname | MP first name |
| mp_id | MP id |
| gender | MP gender |
| county_id | Id of county MP represented |
| party_id | Id of party MP represented |
| substitute_mp | Logical for whether MP is a substitute |
| period_id | Id of period represented in |