Parliamentary committees in specified session
Source:R/get_session_committees.R
get_session_committees.RdA function for retrieving Norwegian parliamentary committees for a specified parliamentary session
Arguments
- sessionid
Character string, or a vector of strings, indicating the id of the parliamentary session to retrieve.
- good_manners
Integer. Seconds delay between calls when making multiple calls to the same function. Note that the Stortinget API is limited to 100 calls per minute (see https://data.stortinget.no/nyhetsoversikt/begrensning-pa-api-kall/).
Value
A data.frame with the following variables:
| response_date | Date of data retrieval |
| version | Data version from the API |
| id | Committee id |
| name | Committee name |
| session_id | Session id |