| |
| response_date | Date of data retrieval |
| version | Data version from the API |
| session_id | Session id |
| agenda_number | Agenda number within the session |
| footnote | Footnotes for the meeting |
| meeting_id | Meeting id |
| no_meeting_text | Description of why there was no meeting, if relevant |
| evening_meeting | Whether the meeting was an evening meeting or not |
| note | Note for the meeting |
| meeting_date | Date the meeting took place |
| meeting_order | Indicator for meeting order |
| meeting_place | Where the meeting took place |
| transcript_id | Id for transcript (usually empty) |
| additional_agenda | Logical indicator for whether there was additional agenda to the meeting |