Skip to contents

A function for retrieving one of several publication types within a parliamentary session.

Usage

get_session_publications(sessionid = NA, type = "referat", good_manners = 0)

Arguments

sessionid

Character string, or a vector of strings, indicating the id of the session to retrieve publications from.

type

Character specifying type of publication to download. Available types are "referat" (minutes), "innstilling" (proposition), "innberetning" (report), "lovvedtak" (law decision), "lovanmerkning" (law note), "dok8" (MP proposal) "dok12" (Constitutional proposal), and "dokumentserie" (document series). Defaults to "referat".

good_manners

Integer. Seconds delay between calls when making multiple calls to the same function. Note that the Stortinget API is limited to 100 calls per minute (see https://data.stortinget.no/nyhetsoversikt/begrensning-pa-api-kall/).

Value

A data.frame with the following variables:

response_dateDate of data retrieval
versionData version from the API
session_idSession id
publication_dateDate of publication
publication_idId of publication
publication_formatPublication format (XML)
publication_available_dateWhen the publication was made available
publication_titlePublication title
publication_typePublication type

See also

Examples


if (FALSE) { # \dontrun{

pub <- get_session_publications("1998-99")
head(pub)

} # }