Retrieve written input for a specified hearing
Source:R/get_written_hearing_input.R
get_written_hearing_input.RdA function for retrieving written input for a specified hearing
Arguments
- hearingid
Character string, or a vector of strings, indicating the id of the hearing to retrieve.
- good_manners
Integer. Seconds delay between calls when making multiple calls to the same function. Note that the Stortinget API is limited to 100 calls per minute (see https://data.stortinget.no/nyhetsoversikt/begrensning-pa-api-kall/).
Value
A data.frame the following variables:
| response_date | Date of data retrieval |
| version | Data version from the API |
| hearing_id | Id of the hearing |
| hearing_type | Type of hearing |
| committee_id | Id of committee responsible for the hearing |
| hearing_input_date | Date of receiving input |
| hearing_input_id | Hearing input id |
| hearing_input_organization | Organization giving input |
| hearing_input_text | Full text of the hearing input |
| hearing_input_title | Title of the hearing input |